The name of the logical column added to @data by filter() (from
surveytidy) to mark domain membership. Exposed here so that sibling
packages (surveytidy, surveyweights) can reference it without
using :::.
The name of the logical column added to @data by filter() (from
surveytidy) to mark domain membership. Exposed here so that sibling
packages (surveytidy, surveyweights) can reference it without
using :::.