Skip to contents

Sets question preface text for multiple variables at once using named arguments.

Usage

set_question_prefaces(x, ...)

Arguments

x

A survey design object.

...

Named arguments where the name is the variable (unquoted) and the value is the preface string.

Value

The modified survey object, invisibly.