Skip to contents

Sets analyst notes for multiple variables at once using named arguments.

Usage

set_variable_notes(x, ...)

Arguments

x

A survey design object.

...

Named arguments where the name is the variable (unquoted) and the value is the note string.

Value

The modified survey object, invisibly.