Sets missing-value codes for one or more variables. Missing codes are atomic
vectors documenting which data values represent missing data
(e.g., c(Refused = -2L, DontKnow = -1L)).
Named arguments where the name is the variable and the value is
a named atomic vector of missing codes. Supports !!! list splicing.
variable
A character vector of variable names. Use with codes.
codes
A list of named atomic vectors, one per element of variable.
When variable has length 1, a bare named atomic vector is also accepted.
Details
Supports Conventions 1, 2, and 3 — see set_var_label() for details on
the calling conventions. For Convention 3 with a single variable, a bare
named atomic vector is accepted in addition to a list.