Skip to contents

Sets the question preface string for one or more variables. Question prefaces are the shared introductory text for a battery of related questions.

Usage

set_question_preface(x, ..., variable = NULL, preface = NULL)

Arguments

x

A survey design object or a data frame.

...

Named arguments where the name is the variable and the value is the preface string. Supports !!! list splicing.

variable

A character vector of variable names. Use with preface.

preface

A character vector of preface strings, one per element of variable.

Value

The modified object, invisibly.

Details

Supports Conventions 1, 2, and 3 — see set_var_label() for details.

Examples

d <- as_survey(gss_2024, ids = vpsu, weights = wtssps,
               strata = vstrat, nest = TRUE)
d <- set_question_preface(d, happy = "Taken all together...")
extract_question_preface(d, happy)
#>                   happy 
#> "Taken all together..."