Skip to contents

Sets the question preface string for a single variable in a survey design object. Question prefaces are the shared introductory text for a battery of related questions.

Usage

set_question_preface(x, var, preface)

Arguments

x

A survey design object.

var

<data-masked> Variable name (bare, unquoted).

preface

A character string. The question preface text.

Value

The modified survey object, invisibly.