Sets the question preface string for a single variable in a survey design object. Question prefaces are the shared introductory text for a battery of related questions.
Arguments
- x
A survey design object.
- var
<
data-masked> Variable name (bare, unquoted).- preface
A character string. The question preface text.
See also
set_question_prefaces() for setting prefaces for multiple
variables, extract_question_preface() to retrieve a preface
Other metadata:
extract_question_preface(),
extract_val_labels(),
extract_var_label(),
extract_var_note(),
infer_question_prefaces(),
set_question_prefaces(),
set_val_labels(),
set_value_labels(),
set_var_label(),
set_var_note(),
set_variable_labels(),
set_variable_notes(),
survey_metadata(),
survey_weighting_history()