Learn R Programming

surveycore (version 0.8.3)

set_question_preface: Set Question Preface(s)

Description

Sets the question preface string for one or more variables. Question prefaces are the shared introductory text for a battery of related questions.

Usage

set_question_preface(x, ..., variable = NULL, preface = NULL)

Value

The modified object, invisibly.

Arguments

x

A survey design object or a data frame.

...

Named arguments where the name is the variable and the value is the preface string. Supports !!! list splicing.

variable

A character vector of variable names. Use with preface.

preface

A character vector of preface strings, one per element of variable.

Details

Supports Conventions 1, 2, and 3 — see set_var_label() for details.

See Also

extract_question_preface() to retrieve a preface

Other metadata: classify_question_type(), extract_metadata(), extract_missing_codes(), extract_question_preface(), extract_sata(), extract_universe(), extract_val_labels(), extract_var_label(), extract_var_note(), infer_question_prefaces(), set_missing_codes(), set_sata(), set_universe(), set_val_labels(), set_var_label(), set_var_note(), survey_metadata(), survey_weighting_history()

Examples

Run this code
d <- as_survey(gss_2024, ids = vpsu, weights = wtssps,
               strata = vstrat, nest = TRUE)
d <- set_question_preface(d, happy = "Taken all together...")
extract_question_preface(d, happy)

Run the code above in your browser using DataLab