Sets an analyst note for a single variable in a survey design object. Notes are free-text annotations for documenting processing decisions, data quality concerns, or other context.
Arguments
- x
A survey design object.
- var
<
data-masked> Variable name (bare, unquoted).- note
A character string. The analyst note to attach.
See also
set_variable_notes() for setting notes for multiple variables,
extract_var_note() to retrieve a note
Other metadata:
extract_question_preface(),
extract_val_labels(),
extract_var_label(),
extract_var_note(),
infer_question_prefaces(),
set_question_preface(),
set_question_prefaces(),
set_val_labels(),
set_value_labels(),
set_var_label(),
set_variable_labels(),
set_variable_notes(),
survey_metadata(),
survey_weighting_history()