survey_data: Access the Data Component of a Survey Design Object
Description
Returns the underlying data frame stored in a survey design object.
This is a thin accessor for x@data that provides a stable public name
independent of the S7 property structure.
Usage
survey_data(x)
Value
A data.frame with all variables, including design variables.
Arguments
x
A survey_taylor, survey_replicate, or survey_twophase object.