A survey design object using replicate weights for variance estimation.
Create with as_survey_replicate().
Usage
survey_replicate(
data = data.frame(),
metadata = survey_metadata(),
variables = list(),
groups = character(0),
call = NULL
)Arguments
- data
A
data.framecontaining the survey data. Preferas_survey_replicate()over calling this constructor directly.- metadata
A survey_metadata object. Created automatically by
as_survey_replicate().- variables
A named list of design specification (weights, repweights, type, scale, rscales, fpc, fpctype, mse). Set automatically by
as_survey_replicate().- groups
Set by surveytidy's
group_by(). Alwayscharacter(0)in standalone surveycore use.- call
Language object capturing the construction call.
Design variables (@variables)
weightsCharacter string naming the weight column.
repweightsCharacter vector of replicate weight column names. The replicate weight matrix is computed on demand from
design@data[, design@variables$repweights]— it is not stored as a property.typeReplicate weight method: one of
"JK1","JK2","JKn","BRR","Fay","bootstrap","ACS","successive-difference", or"other".scaleNumeric scaling factor for variance estimation.
rscalesNumeric vector of replicate-specific scales, or
NULL.fpcFPC column name or
NULL.fpctype"fraction"or"correction".mseLogical. Use MSE estimates?
See also
as_survey_replicate() to create a survey_replicate object.
Other constructors:
as_survey(),
as_survey_nonprob(),
as_survey_replicate(),
as_survey_twophase(),
survey_data(),
survey_glm(),
survey_glm_fit(),
survey_nonprob(),
survey_taylor(),
survey_twophase()
Examples
# Prefer as_survey_replicate() over calling survey_replicate() directly
set.seed(1)
df <- data.frame(y = rnorm(20), wt = runif(20, 1, 3),
rep1 = runif(20, 0.5, 2), rep2 = runif(20, 0.5, 2))
d <- as_survey_replicate(df, weights = wt,
repweights = starts_with("rep"), type = "BRR")
class(d)
#> [1] "surveycore::survey_replicate" "surveycore::survey_base"
#> [3] "S7_object"