Returns the list of weighting operations recorded on a survey design object. Each entry is appended by surveyweights after a calibration or nonresponse adjustment step. Returns an empty list when no history has been recorded.
Value
A list of history entries, or list() if no history is present.
See also
Other metadata:
extract_question_preface(),
extract_val_labels(),
extract_var_label(),
extract_var_note(),
infer_question_prefaces(),
set_question_preface(),
set_question_prefaces(),
set_val_labels(),
set_value_labels(),
set_var_label(),
set_var_note(),
set_variable_labels(),
set_variable_notes(),
survey_metadata()
Examples
d <- as_survey(nhanes_2017, ids = sdmvpsu, weights = wtint2yr,
strata = sdmvstra, nest = TRUE)
survey_weighting_history(d) # list() — no weighting history
#> list()